{% extends 'mailer/layout.html' %}

{% block content %}
  <h1>You have been invited to Vaultier</h1>

  <p>
      Please use following url to accept invitation:
  </p>

    <p>
       <a href="{{ url }}">{{ url }}</a>
    </p>

  <p>Thanks, you rock!</p>
{% endblock %}